pub struct NoCache;Expand description
This ‘cache’ does not in fact cache anything, so using it for the parser cache disables caching entirely. This will not change the end result of parsing any given input, but it will result in a loss of speed in exchange for lower memory requirements.